@@ -1,14 +1,11 @@
-//! Kademlia errors
+//! DHT errors
 
 use crate::message::ErrorMessage;
-use futures::{
-    channel::mpsc::{SendError, TrySendError},
-    task::SpawnError,
-};
+use futures::channel::mpsc::{SendError, TrySendError};
 use std::io;
 use thiserror::Error;
 
-/// Kademlia errors
+/// DHT errors
 #[derive(Debug, Error)]
 pub enum Error {
     /// An I/O error has occurred.
@@ -23,28 +20,16 @@ pub enum Error {
     #[error("a peer sent an error reply: {0:}")]
     ErrorReply(#[from] ErrorMessage),
 
-    /// Spawning a task failed
-    #[error("spawning a task failed: {0:}")]
-    SpawnFailure(#[from] SpawnError),
-
     /// A query has timed out
     #[error("a query has timed out")]
     Timeout,
 
-    /// An invalid transaction ID was provided
-    #[error("an invalid transaction ID was provided")]
-    InvalidTransaction,
-
     /// Sending a message failed
     #[error("sending a message failed")]
     SendFailure,
 
-    /// Bootstrapping failed
-    #[error("bootstrapping failed")]
-    BootstrapFailure,
-
-    #[cfg(test)]
-    #[error("receiving from a channel failed")]
+    /// Receiving a message failed
+    #[error("receiving a message failed")]
     ReceiveFailure,
 }
 
@@ -55,16 +40,24 @@ impl From<serde_bencode::Error> for Error {
 }
 
 impl<T> From<TrySendError<T>> for Error {
-    fn from(e: TrySendError<T>) -> Self {
+    fn from(_: TrySendError<T>) -> Self {
         Error::SendFailure
     }
 }
 
 impl From<SendError> for Error {
-    fn from(e: SendError) -> Self {
+    fn from(_: SendError) -> Self {
         Error::SendFailure
     }
 }
 
-/// Result type for Kademlia errors.
+impl From<async_std::channel::RecvError> for Error {
+    fn from(_: async_std::channel::RecvError) -> Self {
+        Error::ReceiveFailure
+    }
+}
+
+/// Result type for DHT errors.
 pub type Result<T> = std::result::Result<T, Error>;
+
+// TODO clean up internal errors
