@@ -1,7 +1,10 @@
 //! Kadmelia distributed hash table
 #![warn(missing_docs)]
-#![feature(drain_filter, btree_drain_filter, map_first_last, duration_constants)]
-#![allow(unused_variables, dead_code)]
+#![feature(drain_filter)]
+#![feature(btree_drain_filter)]
+#![feature(map_first_last)]
+#![feature(duration_constants)]
+#![allow(dead_code)]
 
 mod directory;
 mod error;
@@ -20,6 +23,6 @@ mod txid;
 mod testnet;
 
 pub use error::{Error, Result};
-pub use id::InfoHash;
-pub use node::{Node, SearchHandle};
+pub use id::{Id, InfoHash};
+pub use node::{Announce, Handle, Node, Router};
 pub use transport::Transport;
