@@ -43,13 +43,21 @@ pub enum Message {
 }
 
 impl Message {
-    pub(crate) fn set_my_id(&mut self, my_id: Id) {
+    pub fn set_id(&mut self, my_id: Id) {
         match self {
-            Message::Query { message, .. } => message.set_my_id(my_id),
-            Message::Response { message, .. } => message.set_my_id(my_id),
+            Message::Query { message, .. } => message.set_id(my_id),
+            Message::Response { message, .. } => message.set_id(my_id),
             _ => {}
         }
     }
+
+    pub fn id(&self) -> Option<Id> {
+        match self {
+            Message::Query { message, .. } => Some(message.id()),
+            Message::Response { message, .. } => Some(message.id()),
+            _ => None,
+        }
+    }
 }
 
 /// A query message
@@ -104,6 +112,15 @@ impl QueryMessage {
         }
     }
 
+    pub fn id(&self) -> Id {
+        match self {
+            Self::Ping { id } => *id,
+            Self::FindNode { id, .. } => *id,
+            Self::GetPeers { id, .. } => *id,
+            Self::AnnouncePeer { id, .. } => *id,
+        }
+    }
+
     pub fn expected_response(&self) -> ExpectedResponse {
         match self {
             Self::Ping { .. } => ExpectedResponse::Pong,
@@ -113,7 +130,7 @@ impl QueryMessage {
         }
     }
 
-    fn set_my_id(&mut self, my_id: Id) {
+    fn set_id(&mut self, my_id: Id) {
         match self {
             Self::Ping { id } => *id = my_id,
             Self::FindNode { id, .. } => *id = my_id,
@@ -281,12 +298,10 @@ impl TryFrom<PortSerial> for Port {
     fn try_from(port: PortSerial) -> Result<Self> {
         if port.implied_port {
             Ok(Self::Implicit)
+        } else if port.port != 0 {
+            Ok(Self::Explicit(port.port))
         } else {
-            if port.port != 0 {
-                Ok(Self::Explicit(port.port))
-            } else {
-                Err(Error::ParseFailure("bad port".into()))
-            }
+            Err(Error::ParseFailure("bad port".into()))
         }
     }
 }
@@ -440,7 +455,7 @@ impl ResponseMessage {
         }
     }
 
-    fn set_my_id(&mut self, my_id: Id) {
+    fn set_id(&mut self, my_id: Id) {
         self.id = my_id;
     }
 }
