@@ -9,7 +9,7 @@ pub struct Timer {
 }
 
 impl Timer {
-    pub fn new(length: Duration) -> Self {
+    pub fn start(length: Duration) -> Self {
         Self {
             length,
             end: clock::now() + length,
@@ -21,6 +21,7 @@ impl Timer {
     }
 
     pub fn postpone(&mut self, other: &Self) {
+        assert!(self.length == other.length);
         if other.end > self.end {
             self.end = other.end
         }
